# share-pro

Share your computer files to android over wifi.

 [![PyPI version](https://badge.fury.io/py/share-pro.svg)](https://pypi.org/project/share-pro/)
 [![Downloads](https://pepy.tech/badge/share-pro/month)](https://pepy.tech/project/share-pro)
 [![Downloads](https://static.pepy.tech/personalized-badge/share-pro?period=total&units=international_system&left_color=green&right_color=blue&left_text=Total%20Downloads)](https://pepy.tech/project/share-pro)


## Installation

```sh
pip3 install share-pro
```

## Usage

```sh
share-pro
```
